@@ -6,7 +6,7 @@
 #include <qpdf/QPDFAnnotationObjectHelper.hh>
 #include <qpdf/QTC.hh>
 #include <qpdf/QUtil.hh>
-#include <stdlib.h>
+#include <cstdlib>
 
 QPDFFormFieldObjectHelper::QPDFFormFieldObjectHelper(QPDFObjectHandle oh) :
     QPDFObjectHelper(oh),
@@ -36,20 +36,14 @@ QPDFFormFieldObjectHelper
 QPDFFormFieldObjectHelper::getTopLevelField(bool* is_different)
 {
     auto top_field = this->oh;
-    std::set<QPDFObjGen> seen;
-    while (top_field.isDictionary() &&
-           (!top_field.getKey("/Parent").isNull())) {
+    QPDFObjGen::set seen;
+    while (seen.add(top_field) && !top_field.getKeyIfDict("/Parent").isNull()) {
         top_field = top_field.getKey("/Parent");
         if (is_different) {
             *is_different = true;
         }
-        auto og = top_field.getObjGen();
-        if (seen.count(og)) {
-            break;
-        }
-        seen.insert(og);
     }
-    return QPDFFormFieldObjectHelper(top_field);
+    return {top_field};
 }
 
 QPDFObjectHandle
@@ -76,25 +70,22 @@ QPDFFormFieldObjectHelper::getInheritableFieldValue(std::string const& name)
         return QPDFObjectHandle::newNull();
     }
     QPDFObjectHandle result(node.getKey(name));
-    std::set<QPDFObjGen> seen;
-    while (result.isNull() && node.hasKey("/Parent")) {
-        seen.insert(node.getObjGen());
-        node = node.getKey("/Parent");
-        if (seen.count(node.getObjGen())) {
-            break;
-        }
-        result = node.getKey(name);
-        if (!result.isNull()) {
-            QTC::TC(
-                "qpdf", "QPDFFormFieldObjectHelper non-trivial inheritance");
+    if (result.isNull()) {
+        QPDFObjGen::set seen;
+        while (seen.add(node) && node.hasKey("/Parent")) {
+            node = node.getKey("/Parent");
+            result = node.getKey(name);
+            if (!result.isNull()) {
+                QTC::TC("qpdf", "QPDFFormFieldObjectHelper non-trivial inheritance");
+                return result;
+            }
         }
     }
     return result;
 }
 
 std::string
-QPDFFormFieldObjectHelper::getInheritableFieldValueAsString(
-    std::string const& name)
+QPDFFormFieldObjectHelper::getInheritableFieldValueAsString(std::string const& name)
 {
     QPDFObjectHandle fv = getInheritableFieldValue(name);
     std::string result;
@@ -105,8 +96,7 @@ QPDFFormFieldObjectHelper::getInheritableFieldValueAsString(
 }
 
 std::string
-QPDFFormFieldObjectHelper::getInheritableFieldValueAsName(
-    std::string const& name)
+QPDFFormFieldObjectHelper::getInheritableFieldValueAsName(std::string const& name)
 {
     QPDFObjectHandle fv = getInheritableFieldValue(name);
     std::string result;
@@ -127,18 +117,15 @@ QPDFFormFieldObjectHelper::getFullyQualifiedName()
 {
     std::string result;
     QPDFObjectHandle node = this->oh;
-    std::set<QPDFObjGen> seen;
-    while ((!node.isNull()) && (seen.count(node.getObjGen()) == 0)) {
+    QPDFObjGen::set seen;
+    while (!node.isNull() && seen.add(node)) {
         if (node.getKey("/T").isString()) {
             if (!result.empty()) {
-                QTC::TC(
-                    "qpdf",
-                    "QPDFFormFieldObjectHelper non-trivial qualified name");
+                QTC::TC("qpdf", "QPDFFormFieldObjectHelper non-trivial qualified name");
                 result = "." + result;
             }
             result = node.getKey("/T").getUTF8Value() + result;
         }
-        seen.insert(node.getObjGen());
         node = node.getKey("/Parent");
     }
     return result;
@@ -217,10 +204,7 @@ QPDFFormFieldObjectHelper::getDefaultAppearance()
     }
     std::string result;
     if (value.isString()) {
-        QTC::TC(
-            "qpdf",
-            "QPDFFormFieldObjectHelper DA present",
-            looked_in_acroform ? 0 : 1);
+        QTC::TC("qpdf", "QPDFFormFieldObjectHelper DA present", looked_in_acroform ? 0 : 1);
         result = value.getUTF8Value();
     }
     return result;
@@ -237,10 +221,7 @@ QPDFFormFieldObjectHelper::getQuadding()
     }
     int result = 0;
     if (fv.isInteger()) {
-        QTC::TC(
-            "qpdf",
-            "QPDFFormFieldObjectHelper Q present",
-            looked_in_acroform ? 0 : 1);
+        QTC::TC("qpdf", "QPDFFormFieldObjectHelper Q present", looked_in_acroform ? 0 : 1);
         result = QIntC::to_int(fv.getIntValue());
     }
     return result;
@@ -262,25 +243,19 @@ QPDFFormFieldObjectHelper::isText()
 bool
 QPDFFormFieldObjectHelper::isCheckbox()
 {
-    return (
-        (getFieldType() == "/Btn") &&
-        ((getFlags() & (ff_btn_radio | ff_btn_pushbutton)) == 0));
+    return ((getFieldType() == "/Btn") && ((getFlags() & (ff_btn_radio | ff_btn_pushbutton)) == 0));
 }
 
 bool
 QPDFFormFieldObjectHelper::isRadioButton()
 {
-    return (
-        (getFieldType() == "/Btn") &&
-        ((getFlags() & ff_btn_radio) == ff_btn_radio));
+    return ((getFieldType() == "/Btn") && ((getFlags() & ff_btn_radio) == ff_btn_radio));
 }
 
 bool
 QPDFFormFieldObjectHelper::isPushbutton()
 {
-    return (
-        (getFieldType() == "/Btn") &&
-        ((getFlags() & ff_btn_pushbutton) == ff_btn_pushbutton));
+    return ((getFieldType() == "/Btn") && ((getFlags() & ff_btn_pushbutton) == ff_btn_pushbutton));
 }
 
 bool
@@ -310,15 +285,13 @@ QPDFFormFieldObjectHelper::getChoices()
 }
 
 void
-QPDFFormFieldObjectHelper::setFieldAttribute(
-    std::string const& key, QPDFObjectHandle value)
+QPDFFormFieldObjectHelper::setFieldAttribute(std::string const& key, QPDFObjectHandle value)
 {
     this->oh.replaceKey(key, value);
 }
 
 void
-QPDFFormFieldObjectHelper::setFieldAttribute(
-    std::string const& key, std::string const& utf8_value)
+QPDFFormFieldObjectHelper::setFieldAttribute(std::string const& key, std::string const& utf8_value)
 {
     this->oh.replaceKey(key, QPDFObjectHandle::newUnicodeString(utf8_value));
 }
@@ -331,33 +304,29 @@ QPDFFormFieldObjectHelper::setV(QPDFObjectHandle value, bool need_appearances)
             bool okay = false;
             if (value.isName()) {
                 std::string name = value.getName();
-                if ((name == "/Yes") || (name == "/Off")) {
-                    okay = true;
-                    setCheckBoxValue((name == "/Yes"));
-                }
+                okay = true;
+                // Accept any value other than /Off to mean checked. Files have been seen that use
+                // /1 or other values.
+                setCheckBoxValue((name != "/Off"));
             }
             if (!okay) {
                 this->oh.warnIfPossible(
-                    "ignoring attempt to set a checkbox field to a"
-                    " value of other than /Yes or /Off");
+                    "ignoring attempt to set a checkbox field to a value whose type is not name");
             }
         } else if (isRadioButton()) {
             if (value.isName()) {
                 setRadioButtonValue(value);
             } else {
                 this->oh.warnIfPossible(
-                    "ignoring attempt to set a radio button field to"
-                    " an object that is not a name");
+                    "ignoring attempt to set a radio button field to an object that is not a name");
             }
         } else if (isPushbutton()) {
-            this->oh.warnIfPossible(
-                "ignoring attempt set the value of a pushbutton field");
+            this->oh.warnIfPossible("ignoring attempt set the value of a pushbutton field");
         }
         return;
     }
     if (value.isString()) {
-        setFieldAttribute(
-            "/V", QPDFObjectHandle::newUnicodeString(value.getUTF8Value()));
+        setFieldAttribute("/V", QPDFObjectHandle::newUnicodeString(value.getUTF8Value()));
     } else {
         setFieldAttribute("/V", value);
     }
@@ -370,8 +339,7 @@ QPDFFormFieldObjectHelper::setV(QPDFObjectHandle value, bool need_appearances)
 }
 
 void
-QPDFFormFieldObjectHelper::setV(
-    std::string const& utf8_value, bool need_appearances)
+QPDFFormFieldObjectHelper::setV(std::string const& utf8_value, bool need_appearances)
 {
     setV(QPDFObjectHandle::newUnicodeString(utf8_value), need_appearances);
 }
@@ -379,26 +347,20 @@ QPDFFormFieldObjectHelper::setV(
 void
 QPDFFormFieldObjectHelper::setRadioButtonValue(QPDFObjectHandle name)
 {
-    // Set the value of a radio button field. This has the following
-    // specific behavior:
-    // * If this is a radio button field that has a parent that is
-    //   also a radio button field and has no explicit /V, call itself
-    //   on the parent
-    // * If this is a radio button field with children, set /V to the
-    //   given value. Then, for each child, if the child has the
-    //   specified value as one of its keys in the /N subdictionary of
-    //   its /AP (i.e. its normal appearance stream dictionary), set
-    //   /AS to name; otherwise, if /Off is a member, set /AS to /Off.
-    // Note that we never turn on /NeedAppearances when setting a
-    // radio button field.
+    // Set the value of a radio button field. This has the following specific behavior:
+    // * If this is a radio button field that has a parent that is also a radio button field and has
+    //   no explicit /V, call itself on the parent
+    // * If this is a radio button field with children, set /V to the given value. Then, for each
+    //   child, if the child has the specified value as one of its keys in the /N subdictionary of
+    //   its /AP (i.e. its normal appearance stream dictionary), set /AS to name; otherwise, if /Off
+    //   is a member, set /AS to /Off.
+    // Note that we never turn on /NeedAppearances when setting a radio button field.
     QPDFObjectHandle parent = this->oh.getKey("/Parent");
     if (parent.isDictionary() && parent.getKey("/Parent").isNull()) {
         QPDFFormFieldObjectHelper ph(parent);
         if (ph.isRadioButton()) {
-            // This is most likely one of the individual buttons. Try
-            // calling on the parent.
-            QTC::TC(
-                "qpdf", "QPDFFormFieldObjectHelper set parent radio button");
+            // This is most likely one of the individual buttons. Try calling on the parent.
+            QTC::TC("qpdf", "QPDFFormFieldObjectHelper set parent radio button");
             ph.setRadioButtonValue(name);
             return;
         }
@@ -406,8 +368,9 @@ QPDFFormFieldObjectHelper::setRadioButtonValue(QPDFObjectHandle name)
 
     QPDFObjectHandle kids = this->oh.getKey("/Kids");
     if (!(isRadioButton() && parent.isNull() && kids.isArray())) {
-        this->oh.warnIfPossible("don't know how to set the value"
-                                " of this field as a radio button");
+        this->oh.warnIfPossible(
+            "don't know how to set the value"
+            " of this field as a radio button");
         return;
     }
     setFieldAttribute("/V", name);
@@ -417,8 +380,7 @@ QPDFFormFieldObjectHelper::setRadioButtonValue(QPDFObjectHandle name)
         QPDFObjectHandle AP = kid.getKey("/AP");
         QPDFObjectHandle annot;
         if (AP.isNull()) {
-            // The widget may be below. If there is more than one,
-            // just find the first one.
+            // The widget may be below. If there is more than one, just find the first one.
             QPDFObjectHandle grandkids = kid.getKey("/Kids");
             if (grandkids.isArray()) {
                 int ngrandkids = grandkids.getArrayNItems();
@@ -426,9 +388,7 @@ QPDFFormFieldObjectHelper::setRadioButtonValue(QPDFObjectHandle name)
                     QPDFObjectHandle grandkid = grandkids.getArrayItem(j);
                     AP = grandkid.getKey("/AP");
                     if (!AP.isNull()) {
-                        QTC::TC(
-                            "qpdf",
-                            "QPDFFormFieldObjectHelper radio button grandkid");
+                        QTC::TC("qpdf", "QPDFFormFieldObjectHelper radio button grandkid");
                         annot = grandkid;
                         break;
                     }
@@ -437,10 +397,9 @@ QPDFFormFieldObjectHelper::setRadioButtonValue(QPDFObjectHandle name)
         } else {
             annot = kid;
         }
-        if (!annot.isInitialized()) {
+        if (!annot) {
             QTC::TC("qpdf", "QPDFObjectHandle broken radio button");
-            this->oh.warnIfPossible(
-                "unable to set the value of this radio button");
+            this->oh.warnIfPossible("unable to set the value of this radio button");
             continue;
         }
         if (AP.isDictionary() && AP.getKey("/N").isDictionary() &&
@@ -457,9 +416,6 @@ QPDFFormFieldObjectHelper::setRadioButtonValue(QPDFObjectHandle name)
 void
 QPDFFormFieldObjectHelper::setCheckBoxValue(bool value)
 {
-    // Set /AS to /Yes or /Off in addition to setting /V.
-    QPDFObjectHandle name = QPDFObjectHandle::newName(value ? "/Yes" : "/Off");
-    setFieldAttribute("/V", name);
     QPDFObjectHandle AP = this->oh.getKey("/AP");
     QPDFObjectHandle annot;
     if (AP.isNull()) {
@@ -472,9 +428,7 @@ QPDFFormFieldObjectHelper::setCheckBoxValue(bool value)
                 QPDFObjectHandle kid = kids.getArrayItem(i);
                 AP = kid.getKey("/AP");
                 if (!AP.isNull()) {
-                    QTC::TC(
-                        "qpdf",
-                        "QPDFFormFieldObjectHelper checkbox kid widget");
+                    QTC::TC("qpdf", "QPDFFormFieldObjectHelper checkbox kid widget");
                     annot = kid;
                     break;
                 }
@@ -483,7 +437,30 @@ QPDFFormFieldObjectHelper::setCheckBoxValue(bool value)
     } else {
         annot = this->oh;
     }
-    if (!annot.isInitialized()) {
+    std::string on_value;
+    if (value) {
+        // Set the "on" value to the first value in the appearance stream's normal state dictionary
+        // that isn't /Off. If not found, fall back to /Yes.
+        if (AP.isDictionary()) {
+            auto N = AP.getKey("/N");
+            if (N.isDictionary()) {
+                for (auto const& iter: N.ditems()) {
+                    if (iter.first != "/Off") {
+                        on_value = iter.first;
+                        break;
+                    }
+                }
+            }
+        }
+        if (on_value.empty()) {
+            on_value = "/Yes";
+        }
+    }
+
+    // Set /AS to the on value or /Off in addition to setting /V.
+    QPDFObjectHandle name = QPDFObjectHandle::newName(value ? on_value : "/Off");
+    setFieldAttribute("/V", name);
+    if (!annot) {
         QTC::TC("qpdf", "QPDFObjectHandle broken checkbox");
         this->oh.warnIfPossible("unable to set the value of this checkbox");
         return;
@@ -496,9 +473,8 @@ void
 QPDFFormFieldObjectHelper::generateAppearance(QPDFAnnotationObjectHelper& aoh)
 {
     std::string ft = getFieldType();
-    // Ignore field types we don't know how to generate appearances
-    // for. Button fields don't really need them -- see code in
-    // QPDFAcroFormDocumentHelper::generateAppearancesIfNeeded.
+    // Ignore field types we don't know how to generate appearances for. Button fields don't really
+    // need them -- see code in QPDFAcroFormDocumentHelper::generateAppearancesIfNeeded.
     if ((ft == "/Tx") || (ft == "/Ch")) {
         generateTextAppearance(aoh);
     }
@@ -515,9 +491,9 @@ namespace
             std::vector<std::string> const& opt,
             double tf,
             QPDFObjectHandle::Rectangle const& bbox);
-        virtual ~ValueSetter() = default;
-        virtual void handleToken(QPDFTokenizer::Token const&);
-        virtual void handleEOF();
+        ~ValueSetter() override = default;
+        void handleToken(QPDFTokenizer::Token const&) override;
+        void handleEOF() override;
         void writeAppearance();
 
       private:
@@ -526,8 +502,8 @@ namespace
         std::vector<std::string> opt;
         double tf;
         QPDFObjectHandle::Rectangle bbox;
-        enum { st_top, st_bmc, st_emc, st_end } state;
-        bool replaced;
+        enum { st_top, st_bmc, st_emc, st_end } state{st_top};
+        bool replaced{false};
     };
 } // namespace
 
@@ -541,9 +517,7 @@ ValueSetter::ValueSetter(
     V(V),
     opt(opt),
     tf(tf),
-    bbox(bbox),
-    state(st_top),
-    replaced(false)
+    bbox(bbox)
 {
 }
 
@@ -562,8 +536,7 @@ ValueSetter::handleToken(QPDFTokenizer::Token const& token)
         break;
 
     case st_bmc:
-        if ((ttype == QPDFTokenizer::tt_space) ||
-            (ttype == QPDFTokenizer::tt_comment)) {
+        if ((ttype == QPDFTokenizer::tt_space) || (ttype == QPDFTokenizer::tt_comment)) {
             writeToken(token);
         } else {
             state = st_emc;
@@ -601,17 +574,15 @@ ValueSetter::writeAppearance()
 {
     this->replaced = true;
 
-    // This code does not take quadding into consideration because
-    // doing so requires font metric information, which we don't
-    // have in many cases.
+    // This code does not take quadding into consideration because doing so requires font metric
+    // information, which we don't have in many cases.
 
     double tfh = 1.2 * tf;
     int dx = 1;
 
-    // Write one or more lines, centered vertically, possibly with
-    // one row highlighted.
+    // Write one or more lines, centered vertically, possibly with one row highlighted.
 
-    size_t max_rows = static_cast<size_t>((bbox.ury - bbox.lly) / tfh);
+    auto max_rows = static_cast<size_t>((bbox.ury - bbox.lly) / tfh);
     bool highlight = false;
     size_t highlight_idx = 0;
 
@@ -630,8 +601,7 @@ ValueSetter::writeAppearance()
             }
         }
         if (found) {
-            // Try to make the found item the second one, but
-            // adjust for under/overflow.
+            // Try to make the found item the second one, but adjust for under/overflow.
             int wanted_first = QIntC::to_int(found_idx) - 1;
             int wanted_last = QIntC::to_int(found_idx + max_rows) - 2;
             QTC::TC("qpdf", "QPDFFormFieldObjectHelper list found");
@@ -649,9 +619,7 @@ ValueSetter::writeAppearance()
             }
             highlight = true;
             highlight_idx = found_idx - QIntC::to_size(wanted_first);
-            for (size_t i = QIntC::to_size(wanted_first);
-                 i <= QIntC::to_size(wanted_last);
-                 ++i) {
+            for (size_t i = QIntC::to_size(wanted_first); i <= QIntC::to_size(wanted_last); ++i) {
                 lines.push_back(opt.at(i));
             }
         } else {
@@ -668,30 +636,25 @@ ValueSetter::writeAppearance()
 
     // Write the lines centered vertically, highlighting if needed
     size_t nlines = lines.size();
-    double dy = bbox.ury -
-        ((bbox.ury - bbox.lly - (static_cast<double>(nlines) * tfh)) / 2.0);
+    double dy = bbox.ury - ((bbox.ury - bbox.lly - (static_cast<double>(nlines) * tfh)) / 2.0);
     if (highlight) {
         write(
             "q\n0.85 0.85 0.85 rg\n" + QUtil::double_to_string(bbox.llx) + " " +
             QUtil::double_to_string(
-                bbox.lly + dy -
-                (tfh * (static_cast<double>(highlight_idx + 1)))) +
+                bbox.lly + dy - (tfh * (static_cast<double>(highlight_idx + 1)))) +
             " " + QUtil::double_to_string(bbox.urx - bbox.llx) + " " +
             QUtil::double_to_string(tfh) + " re f\nQ\n");
     }
     dy -= tf;
     write("q\nBT\n" + DA + "\n");
     for (size_t i = 0; i < nlines; ++i) {
-        // We could adjust Tm to translate to the beginning the first
-        // line, set TL to tfh, and use T* for each subsequent line,
-        // but doing this would require extracting any Tm from DA,
+        // We could adjust Tm to translate to the beginning the first line, set TL to tfh, and use
+        // T* for each subsequent line, but doing this would require extracting any Tm from DA,
         // which doesn't seem really worth the effort.
         if (i == 0) {
             write(
-                QUtil::double_to_string(bbox.llx + static_cast<double>(dx)) +
-                " " +
-                QUtil::double_to_string(bbox.lly + static_cast<double>(dy)) +
-                " Td\n");
+                QUtil::double_to_string(bbox.llx + static_cast<double>(dx)) + " " +
+                QUtil::double_to_string(bbox.lly + static_cast<double>(dy)) + " Td\n");
         } else {
             write("0 " + QUtil::double_to_string(-tfh) + " Td\n");
         }
@@ -705,34 +668,24 @@ namespace
     class TfFinder: public QPDFObjectHandle::TokenFilter
     {
       public:
-        TfFinder();
-        virtual ~TfFinder()
-        {
-        }
-        virtual void handleToken(QPDFTokenizer::Token const&);
+        TfFinder() = default;
+        ~TfFinder() override = default;
+        void handleToken(QPDFTokenizer::Token const&) override;
         double getTf();
         std::string getFontName();
         std::string getDA();
 
       private:
-        double tf;
-        int tf_idx;
+        double tf{11.0};
+        int tf_idx{-1};
         std::string font_name;
-        double last_num;
-        int last_num_idx;
+        double last_num{0.0};
+        int last_num_idx{-1};
         std::string last_name;
         std::vector<std::string> DA;
     };
 } // namespace
 
-TfFinder::TfFinder() :
-    tf(11.0),
-    tf_idx(-1),
-    last_num(0.0),
-    last_num_idx(-1)
-{
-}
-
 void
 TfFinder::handleToken(QPDFTokenizer::Token const& token)
 {
@@ -753,8 +706,8 @@ TfFinder::handleToken(QPDFTokenizer::Token const& token)
     case QPDFTokenizer::tt_word:
         if (token.isWord("Tf")) {
             if ((last_num > 1.0) && (last_num < 1000.0)) {
-                // These ranges are arbitrary but keep us from doing
-                // insane things or suffering from over/underflow
+                // These ranges are arbitrary but keep us from doing insane things or suffering from
+                // over/underflow
                 tf = last_num;
             }
             tf_idx = last_num_idx;
@@ -783,8 +736,7 @@ TfFinder::getDA()
         if (QIntC::to_int(i) == tf_idx) {
             double delta = strtod(cur.c_str(), nullptr) - this->tf;
             if ((delta > 0.001) || (delta < -0.001)) {
-                // tf doesn't match the font size passed to Tf, so
-                // substitute.
+                // tf doesn't match the font size passed to Tf, so substitute.
                 QTC::TC("qpdf", "QPDFFormFieldObjectHelper fallback Tf");
                 cur = QUtil::double_to_string(tf);
             }
@@ -801,8 +753,7 @@ TfFinder::getFontName()
 }
 
 QPDFObjectHandle
-QPDFFormFieldObjectHelper::getFontFromResource(
-    QPDFObjectHandle resources, std::string const& name)
+QPDFFormFieldObjectHelper::getFontFromResource(QPDFObjectHandle resources, std::string const& name)
 {
     QPDFObjectHandle result;
     if (resources.isDictionary() && resources.getKey("/Font").isDictionary() &&
@@ -813,40 +764,34 @@ QPDFFormFieldObjectHelper::getFontFromResource(
 }
 
 void
-QPDFFormFieldObjectHelper::generateTextAppearance(
-    QPDFAnnotationObjectHelper& aoh)
+QPDFFormFieldObjectHelper::generateTextAppearance(QPDFAnnotationObjectHelper& aoh)
 {
     QPDFObjectHandle AS = aoh.getAppearanceStream("/N");
     if (AS.isNull()) {
         QTC::TC("qpdf", "QPDFFormFieldObjectHelper create AS from scratch");
         QPDFObjectHandle::Rectangle rect = aoh.getRect();
-        QPDFObjectHandle::Rectangle bbox(
-            0, 0, rect.urx - rect.llx, rect.ury - rect.lly);
+        QPDFObjectHandle::Rectangle bbox(0, 0, rect.urx - rect.llx, rect.ury - rect.lly);
         QPDFObjectHandle dict = QPDFObjectHandle::parse(
             "<< /Resources << /ProcSet [ /PDF /Text ] >>"
             " /Type /XObject /Subtype /Form >>");
         dict.replaceKey("/BBox", QPDFObjectHandle::newFromRectangle(bbox));
-        AS = QPDFObjectHandle::newStream(
-            this->oh.getOwningQPDF(), "/Tx BMC\nEMC\n");
+        AS = QPDFObjectHandle::newStream(this->oh.getOwningQPDF(), "/Tx BMC\nEMC\n");
         AS.replaceDict(dict);
         QPDFObjectHandle AP = aoh.getAppearanceDictionary();
         if (AP.isNull()) {
             QTC::TC("qpdf", "QPDFFormFieldObjectHelper create AP from scratch");
-            aoh.getObjectHandle().replaceKey(
-                "/AP", QPDFObjectHandle::newDictionary());
+            aoh.getObjectHandle().replaceKey("/AP", QPDFObjectHandle::newDictionary());
             AP = aoh.getAppearanceDictionary();
         }
         AP.replaceKey("/N", AS);
     }
     if (!AS.isStream()) {
-        aoh.getObjectHandle().warnIfPossible(
-            "unable to get normal appearance stream for update");
+        aoh.getObjectHandle().warnIfPossible("unable to get normal appearance stream for update");
         return;
     }
     QPDFObjectHandle bbox_obj = AS.getDict().getKey("/BBox");
     if (!bbox_obj.isRectangle()) {
-        aoh.getObjectHandle().warnIfPossible(
-            "unable to get appearance stream bounding box");
+        aoh.getObjectHandle().warnIfPossible("unable to get appearance stream bounding box");
         return;
     }
     QPDFObjectHandle::Rectangle bbox = bbox_obj.getArrayAsRectangle();
@@ -871,7 +816,7 @@ QPDFFormFieldObjectHelper::generateTextAppearance(
         QPDFObjectHandle resources = AS.getDict().getKey("/Resources");
         QPDFObjectHandle font = getFontFromResource(resources, font_name);
         bool found_font_in_dr = false;
-        if (!font.isInitialized()) {
+        if (!font) {
             QPDFObjectHandle dr = getDefaultResources();
             font = getFontFromResource(dr, font_name);
             found_font_in_dr = font.isDictionary();
@@ -879,8 +824,7 @@ QPDFFormFieldObjectHelper::generateTextAppearance(
         if (found_font_in_dr && resources.isDictionary()) {
             QTC::TC("qpdf", "QPDFFormFieldObjectHelper get font from /DR");
             if (resources.isIndirect()) {
-                resources = resources.getQPDF().makeIndirectObject(
-                    resources.shallowCopy());
+                resources = resources.getQPDF().makeIndirectObject(resources.shallowCopy());
                 AS.getDict().replaceKey("/Resources", resources);
             }
             // Use mergeResources to force /Font to be local
@@ -905,7 +849,5 @@ QPDFFormFieldObjectHelper::generateTextAppearance(
     }
 
     AS.addTokenFilter(
-        // line-break
-        std::shared_ptr<QPDFObjectHandle::TokenFilter>(
-            new ValueSetter(DA, V, opt, tf, bbox)));
+        std::shared_ptr<QPDFObjectHandle::TokenFilter>(new ValueSetter(DA, V, opt, tf, bbox)));
 }
